/*
 *   snot - the network sniff notemaker
 *   Copyright (C) 2005  Eli Fulkerson
 *
 *   updates and whatnot for 'snot.exe' are likely to be found at http://www.elifulkerson.com
 *
 *   Based on the Practical C++ Socket library, available at the time of writing from:
 *   http://cs.ecs.baylor.edu/~donahoo/practical/CSockets/practical/, by Jeff_Donahoo@Baylor.edu
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "PracticalSocket.h"


#define ECHO_MAX_LENGTH 255
#define UDP_DISCARD 9

using namespace std;


int main(int argc, char *argv[]) {

  if ((argc < 3)) {   // Test for correct number of arguments
    printf("Usage: %s <dummy ip> <message>\n", argv[0]);
	printf("\n");
	printf("...will fire-and-forget a udp packet containing <message> to udp/9 on the IP\n");
	printf("address specified, for the express purpose of embedding <message> into an\n");
	printf("ongoing network sniff log.\n");
	printf("\n");
	printf("<dummy ip> should be a valid, living address on your local subnet.\n");
	printf("\n");
	printf("This utility lives at:  http://www.elifulkerson.com\n");
    exit(1);
  }

  string servAddress = argv[1];             // First arg: server address

  

  char echoString[ECHO_MAX_LENGTH];
  strcpy(echoString, "");  // never trust an empty variable.


  int x;					// good ol 'x, good for loopin'
  
  int tempStringLen = 0;
  int echoStringLen = 0;

  // pre-calculate the cancatanation of all the argv's so the error message will be correct
  
  for (x=2; x<argc;x++)
  {
	tempStringLen = tempStringLen + 1 + strlen(argv[x]);
  }

  if (tempStringLen > ECHO_MAX_LENGTH) {
	printf("Thats %d too many characters! (limit is %d) Is that you, Mike?", tempStringLen - ECHO_MAX_LENGTH, ECHO_MAX_LENGTH);
	exit(1);
  }

  // clump up the rest of the argv into one big echoString orgy
  for (x=2; x<argc;x++)
  {
	sprintf(echoString, "%s %s", echoString, argv[x]);	
  }


  echoStringLen = strlen(echoString);
  if (echoStringLen > ECHO_MAX_LENGTH)
  {
    printf("Echo string too long, but you should never see this!\n");
    exit(1);
  }
  
  
  try {
    UDPSocket sock;
  
    // fire off our string
    sock.sendTo(echoString, echoStringLen, servAddress, UDP_DISCARD);
	
	// never check for a response.  we're done.


	printf("Gesundheit!  (message sent)\n");


  } catch (SocketException &e) {
	printf("Boogers.  %s\n", e.what());
    exit(1);
  }
  
  return 0;
}
